@@ -12,12 +12,6 @@
 
 #include <GeographicLib/Constants.hpp>
 
-#if defined(_MSC_VER)
-// Squelch warnings about dll vs string
-#  pragma warning (push)
-#  pragma warning (disable: 4251)
-#endif
-
 namespace GeographicLib {
 
   /**
@@ -173,8 +167,4 @@ namespace GeographicLib {
 
 } // namespace GeographicLib
 
-#if defined(_MSC_VER)
-#  pragma warning (pop)
-#endif
-
 #endif  // GEOGRAPHICLIB_GEOHASH_HPP
