@@ -10,11 +10,6 @@
 #include <GeographicLib/Georef.hpp>
 #include <GeographicLib/Utility.hpp>
 
-#if defined(_MSC_VER)
-// Squelch warnings about enum-float expressions
-#  pragma warning (disable: 5055)
-#endif
-
 namespace GeographicLib {
 
   using namespace std;
