@@ -9,11 +9,6 @@
 
 #include <GeographicLib/LambertConformalConic.hpp>
 
-#if defined(_MSC_VER)
-// Squelch warnings about enum-float expressions
-#  pragma warning (disable: 5055)
-#endif
-
 namespace GeographicLib {
 
   using namespace std;
