@@ -11,11 +11,6 @@
 #include <GeographicLib/Rhumb.hpp>
 #include <GeographicLib/DST.hpp>
 
-#if defined(_MSC_VER)
-// Squelch warnings about enum-float expressions
-#  pragma warning (disable: 5055)
-#endif
-
 namespace GeographicLib {
 
   using namespace std;
